API Reference
=============

This page contains the detailed API reference for the Perpetual Python package.

PerpetualBooster
---------------

.. autoclass:: perpetual.PerpetualBooster
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__

Sklearn Interface
-----------------

.. autoclass:: perpetual.sklearn.PerpetualClassifier
   :members:
   :show-inheritance:

.. autoclass:: perpetual.sklearn.PerpetualRegressor
   :members:
   :show-inheritance:
